# arpes.analysis.statistics module

**arpes.analysis.statistics.mean\_and\_deviation(data:
xarray.core.dataarray.DataArray, axis=None, name=None)**

> Calculates the mean and standard deviation of a DataArray along an
> axis that corresponds to individual observations. This axis can be
> passed or inferred from a set of standard observation-like axes.
> 
> New data variables are created with names *{name}* and *{name}\_std*.
> If a name is not attached to the DataArray, it should be provided.
> 
>   - Parameters
>     
>       - **data** –
>       - **axis** –
>       - **name** –
> 
>   - Returns
